darkhistory.spec.spectools.get_indx — DarkHistory documentation

# darkhistory.spec.spectools.get_indx

`darkhistory.spec.spectools.` `get_indx`(eng, E)

  Returns index of bin containing E.

  Parameters: | eng : ndarray Energy abscissa E : float You would like to know the bin index containing this energy
  Returns: | float Index of bin that contains E

#### Previous topic

darkhistory.spec.spectools.get_bounds_between

#### Next topic

darkhistory.spec.spectools.get_log_bin_width

### This Page

Show Source